@@ -2,7 +2,7 @@
 /*
  * gr-soapy: Soapy SDR Radio Out-Of-Tree Module
  *
- *  Copyright (C) 2018, 2019, 2020
+ *  Copyright (C) 2018, 2019, 2020, 2021
  *  Libre Space Foundation <http://libre.space>
  *
  *  This program is free software: you can redistribute it and/or modify
@@ -76,7 +76,7 @@ source_impl::source_impl(size_t nchan, const std::string &device,
     throw std::invalid_argument(msg);
   }
 
-  if (nchan != tune_args.size()) {
+  if (nchan != other_settings.size()) {
     std::string msg = name() +  ": Wrong number of channels and settings";
     throw std::invalid_argument(msg);
   }
@@ -140,7 +140,9 @@ source_impl::source_impl(size_t nchan, const std::string &device,
     }
     if (!accept_samp_rate) {
       std::string msg = name() +
-                        ": Unsupported sample rate.  Rate must be in the range";
+                        ": Unsupported sample rate (" +
+                        std::to_string(sampling_rate) +
+                        ").  Rate must be in the range";
       for (SoapySDR::Range &range : sps_range) {
         double min_sps = range.minimum();
         double max_sps = range.maximum();
@@ -743,7 +745,7 @@ source_impl::work(int noutput_items,
         GR_LOG_WARN(d_logger, boost::format("Block stream error."));
         return 0;;
       case SOAPY_SDR_TIMEOUT:
-        break;
+        return 0;
       case SOAPY_SDR_CORRUPTION:
         GR_LOG_WARN(d_logger, boost::format("Block corruption."));
         return 0;
